Changelog
=========

0.3
---

 - New: ``PEP272Cipher`` is a new style class on Python 2.

0.2 (latest stable)
-------------------

 - New: Documentation
 - New: Optional extensions module for more speed. CBC and CFB are now two 
   times faster!
 - Changed: ``PEP272Cipher.IV`` is static now.

0.1
---

 - Initial release.
